@@ -20,6 +20,7 @@ from beartype.typing import (
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._check.checkmagic import (
     ARG_NAME_CONF,
+    ARG_NAME_EXCEPTION_PREFIX,
     ARG_NAME_GETRANDBITS,
     ARG_NAME_GET_VIOLATION,
     ARG_NAME_HINT,
@@ -51,6 +52,7 @@ from beartype._conf.confcls import (
     BeartypeConf,
 )
 from beartype._conf.conftest import die_unless_conf
+from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN_REPR
 from beartype._data.hint.datahinttyping import (
     CallableRaiser,
@@ -61,16 +63,17 @@ from beartype._data.hint.datahinttyping import (
     TypeStack,
 )
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.error.utilerrorraise import (
-    EXCEPTION_PLACEHOLDER,
-    reraise_exception_placeholder,
-)
+from beartype._util.error.utilerrraise import reraise_exception_placeholder
+from beartype._util.error.utilerrwarn import reissue_warnings_placeholder
 from beartype._util.func.utilfuncmake import make_func
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585ref import (
     get_hint_pep484585_ref_names_relative_to)
 from beartype._util.hint.utilhinttest import is_hint_ignorable
 from itertools import count
-from warnings import warn
+from warnings import (
+    catch_warnings,
+    warn,
+)
 
 # ....................{ FACTORIES ~ func                   }....................
 @callable_cached
@@ -80,30 +83,35 @@ def make_func_raiser(
     # rather than by keyword. Care should be taken when refactoring parameters,
     # particularly with respect to parameter position.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-
-    # Mandatory parameters.
     hint: object,
-
-    # Optional parameters.
-    conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
+    conf: BeartypeConf,
+    exception_prefix: str,
 ) -> CallableRaiser:
     '''
     **Type-checking raiser function factory** (i.e., low-level callable
     dynamically generating a pure-Python raiser function testing whether an
-    arbitrary object passed to that tester satisfies the type hint passed to
+    arbitrary object passed to that raiser satisfies the type hint passed to
     this factory and either raising an exception or emitting a warning when that
     object violates that hint).
 
     This factory is memoized for efficiency.
 
+    Caveats
+    -------
+    **This factory intentionally accepts no** ``exception_cls`` **parameter.**
+    Instead, simply set the :attr:`.BeartypeConf.violation_door_type` option of
+    the passed ``conf`` parameter accordingly.
+
     Parameters
     ----------
     hint : object
         Type hint to be type-checked.
-    conf : BeartypeConf, optional
+    conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all settings configuring type-checking for the passed object). Defaults
-        to ``BeartypeConf()``, the default :math:`O(1)` configuration.
+        all settings configuring type-checking for the passed object).
+    exception_prefix : str
+        Human-readable label prefixing the representation of this object in the
+        exception message.
 
     Returns
     -------
@@ -121,6 +129,7 @@ def make_func_raiser(
         hint=hint,
         conf=conf,
         make_code_check=make_code_raiser_hint_object_check,
+        exception_prefix=exception_prefix,
     )
 
 
@@ -137,6 +146,7 @@ def make_func_tester(
 
     # Optional parameters.
     conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
+    exception_prefix: str = 'is_bearable() ',
 ) -> CallableTester:
     '''
     **Type-checking tester function factory** (i.e., low-level callable
@@ -168,12 +178,20 @@ def make_func_tester(
 
     # Defer to this lower-level factory function for great convenience.
     return _make_func_checker(  # type: ignore[return-value]
-        hint=hint, conf=conf, make_code_check=make_code_tester_check)
+        hint=hint,
+        conf=conf,
+        make_code_check=make_code_tester_check,
+        exception_prefix=exception_prefix,
+    )
 
 # ....................{ FACTORIES ~ code                   }....................
 #FIXME: Unit test us up, please.
 @callable_cached
-def make_code_tester_check(hint: object, conf: BeartypeConf) -> CodeGenerated:
+def make_code_tester_check(
+    hint: object,
+    conf: BeartypeConf,
+    exception_prefix : str,
+) -> CodeGenerated:
     '''
     Pure-Python code snippet of a type-checking tester function type-checking an
     arbitrary object against the passed type hint under the passed beartype
@@ -188,6 +206,9 @@ def make_code_tester_check(hint: object, conf: BeartypeConf) -> CodeGenerated:
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
+    exception_prefix : str
+        Human-readable label prefixing the representation of this object in the
+        exception message.
 
     Returns
     -------
@@ -399,7 +420,10 @@ def make_code_raiser_func_pep484_noreturn_check(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_raiser_hint_object_check(
-    hint: object, conf: BeartypeConf) -> CodeGenerated:
+    hint: object,
+    conf: BeartypeConf,
+    exception_prefix: str,
+) -> CodeGenerated:
     '''
     Pure-Python code snippet of a type-checking raiser function type-checking an
     arbitrary object against the passed type hint under the passed beartype
@@ -415,6 +439,9 @@ def make_code_raiser_hint_object_check(
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
+    exception_prefix : str
+        Human-readable label prefixing the representation of this object in the
+        exception message.
 
     Returns
     -------
@@ -451,9 +478,11 @@ def make_code_raiser_hint_object_check(
     )
 
     # Pass hidden parameters to this raiser function exposing:
+    # * The passed exception prefix accessed by this snippet.
     # * The get_hint_object_violation() getter called by the
     #   "CODE_GET_HINT_OBJECT_VIOLATION" snippet.
     # * The passed type hint accessed by this snippet.
+    func_scope[ARG_NAME_EXCEPTION_PREFIX] = exception_prefix
     func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
     func_scope[ARG_NAME_HINT] = hint
 
@@ -488,7 +517,7 @@ _func_checker_name_counter = count(start=0, step=1)
 '''
 **Type-checking function name uniquifier** (i.e., iterator yielding the next
 integer incrementation starting at 0, leveraged by the
-:func:`_make_func_checker` factory to uniquify the names of the type-checking
+:func:`._make_func_checker` factory to uniquify the names of the type-checking
 functions dynamically generated by that factory).
 '''
 
@@ -496,9 +525,9 @@ functions dynamically generated by that factory).
 def _func_checker_ignorable(obj: object) -> bool:
     '''
     **Ignorable type-checking tester function singleton** (i.e., function
-    unconditionally returning ``True``, semantically equivalent to a tester
+    unconditionally returning :data:`True`, semantically equivalent to a tester
     testing whether an arbitrary object passed to this tester satisfies an
-    ignorable PEP-compliant type hint).
+    ignorable type hint).
 
     The :func:`make_func_tester` factory efficiently returns this singleton when
     passed an ignorable type hint rather than inefficiently regenerating a
@@ -510,9 +539,13 @@ def _func_checker_ignorable(obj: object) -> bool:
 # ....................{ PRIVATE ~ factories : func         }....................
 #FIXME: Unit test us up, please.
 def _make_func_checker(
+    # Mandatory parameters.
     hint: object,
     conf: BeartypeConf,
     make_code_check: Callable[..., CodeGenerated],
+
+    # Optional parameters.
+    exception_prefix: str = 'die_if_unbearable() or is_bearable() ',
 ) -> CallableRaiserOrTester:
     '''
     **Type-checking function factory** (i.e., low-level callable dynamically
@@ -527,19 +560,6 @@ def _make_func_checker(
 
     Caveats
     -------
-    **This factory intentionally accepts no** ``exception_prefix``
-    **parameter.** Why? Since that parameter is typically specific to the
-    context-sensitive use case of the caller, accepting that parameter would
-    prevent this factory from memoizing the passed hint with the returned code,
-    which would rather defeat the point. Instead, this factory only:
-
-    * Raises generic non-human-readable exceptions containing the placeholder
-      :attr:`beartype._util.error.utilerrorraise.EXCEPTION_PLACEHOLDER`
-      substring that the caller is required to explicitly catch and raise
-      non-generic human-readable exceptions from by calling the
-      :func:`beartype._util.error.utilerrorraise.reraise_exception_placeholder`
-      function.
-
     **This factory intentionally accepts no** ``exception_cls`` **parameter.**
     Doing so would only ambiguously obscure context-sensitive exceptions raised
     by lower-level utility functions called by this higher-level factory.
@@ -548,14 +568,16 @@ def _make_func_checker(
     ----------
     hint : object
         Type hint to be type-checked.
-    conf : BeartypeConf, optional
+    conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all settings configuring type-checking for the passed object). Defaults
-        to ``BeartypeConf()``, the default :math:`O(1)` configuration.
+        all settings configuring type-checking for the passed object).
     make_code_check : Callable[..., CodeGenerated]
         **Type-checking code factory** (i.e., function dynamically generating a
         code snippet of a function type-checking an arbitrary object against the
         passed type hint under the passed beartype configuration).
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to a reasonably sensible string.
 
     Returns
     -------
@@ -575,8 +597,8 @@ def _make_func_checker(
         portability of calls by users to the resulting type-checker.
     _BeartypeUtilCallableException
         If this function erroneously generates a syntactically invalid
-        type-checking tester function. That should *never* happen, but let's
-        admit that you're still reading this for a reason.
+        type-checking function. That should *never* happen, but let's admit that
+        you're still reading this for a reason.
 
     Warns
     -----
@@ -586,111 +608,123 @@ def _make_func_checker(
 
     # Attempt to...
     try:
-        # ....................{ VALIDATION                 }....................
-        # Else, this configuration is actually a configuration.
-        # If this configuration is *NOT* a configuration, raise an exception.
-        die_unless_conf(conf)
+        # With a context manager "catching" *ALL* non-fatal warnings emitted
+        # during this logic for subsequent "playback" below...
+        with catch_warnings(record=True) as warnings_issued:
+            # ....................{ VALIDATION             }....................
+            # If "conf" is *NOT* a configuration, raise an exception.
+            die_unless_conf(conf)
+            # Else, "conf" is a configuration.
 
-        # Either:
-        # * If this hint is PEP-noncompliant, the PEP-compliant type hint
-        #   converted from this PEP-noncompliant type hint.
-        # * Else if this hint is PEP-compliant and supported, this hint as is.
-        # * Else, raise an exception (i.e., if this hint is neither
-        #   PEP-noncompliant nor a supported PEP-compliant hint).
-        #
-        # Do this first *BEFORE* passing this hint to any further callables.
-        hint = sanify_hint_root_statement(
-            hint=hint, conf=conf, exception_prefix=EXCEPTION_PLACEHOLDER)
+            # Either:
+            # * If this hint is PEP-noncompliant, the PEP-compliant type hint
+            #   converted from this PEP-noncompliant type hint.
+            # * If this hint is PEP-compliant and supported, this hint as is.
+            # * Else, raise an exception (i.e., if this hint is neither
+            #   PEP-noncompliant nor a supported PEP-compliant hint).
+            #
+            # Do this first *BEFORE* passing this hint to any further callables.
+            hint = sanify_hint_root_statement(
+                hint=hint, conf=conf, exception_prefix=EXCEPTION_PLACEHOLDER)
 
-        # If this hint is ignorable, all objects satisfy this hint. In this
-        # case, return a trivial tester function unconditionally returning true.
-        if is_hint_ignorable(hint):
-            return _func_checker_ignorable
-        # Else, this hint is unignorable.
+            # If this hint is ignorable, all objects satisfy this hint. In this
+            # case, return a trivial function unconditionally returning true.
+            if is_hint_ignorable(hint):
+                return _func_checker_ignorable
+            # Else, this hint is unignorable.
 
-        # ....................{ CODE                       }....................
-        # Python code snippet comprising a single boolean expression
-        # type-checking an arbitrary object against this hint.
-        (
-            code_check,
-            func_scope,
-            hint_refs_type_basename,
-        ) = make_code_check(hint, conf)
+            # ....................{ CODE                   }....................
+            # Python code snippet comprising a single boolean expression
+            # type-checking an arbitrary object against this hint.
+            (
+                code_check,
+                func_scope,
+                hint_refs_type_basename,
+            ) = make_code_check(hint, conf, exception_prefix)
 
-        # If this hint contains one or more relative forward references, this
-        # hint is non-portable across lexical scopes. In this case, raise an
-        # exception. Why? Because this hint is relative to and thus valid only
-        # with respect to the caller's current lexical scope. However, there is
-        # *NO* guarantee that the type-checking function created and returned by
-        # this factory resides in the same lexical scope.
-        #
-        # Suppose that type-checking function does, however. Even in that best
-        # case, *ALL* calls to that tester would still be non-portable. Why?
-        # Because those calls would now tacitly assume the original lexical
-        # scope that they were called in. Those calls are now
-        # lexically-dependent and thus could *NOT* be trivially copy-and-pasted
-        # into different lexical scopes (e.g., submodules, classes, or
-        # callables); doing so would raise exceptions at call time, due to being
-        # unable to resolve those references. Preventing users from doing
-        # something that will blow up in their test suites commits after the
-        # fact is not simply a good thing; it's really the only sane thing left.
-        #
-        # Suppose that we didn't particularly care about end user sanity,
-        # however. Even in that worst case, resolving these references would
-        # still be non-trivial, non-portable, and (perhaps most importantly)
-        # incredibly slow. Why? Because doing so would require iteratively
-        # introspecting the call stack for the first callable *NOT* residing in
-        # the "beartype" codebase. These references would then be resolved
-        # against the global and local lexical scope of that callable. While
-        # technically feasible, doing so would render higher-level "beartype"
-        # functions calling this lower-level factory (e.g., our increasingly
-        # popular public beartype.door.is_bearable() and die_if_unbearable()
-        # type-checkers) sufficiently slow as to be pragmatically infeasible.
-        if hint_refs_type_basename:
-            # Defer to a low-level getter to raise a human-readable exception.
-            get_hint_pep484585_ref_names_relative_to(
-                # First relative forward reference in this type hint,
-                # arbitrarily chosen for convenience.
-                hint=hint_refs_type_basename[0],
-                exception_prefix=(
-                    f'{EXCEPTION_PLACEHOLDER}type hint {repr(hint)} '),
+            # If this hint contains one or more relative forward references,
+            # this hint is non-portable across lexical scopes. In this case,
+            # raise an exception. Why? Because this hint is relative to and thus
+            # valid only with respect to the caller's current lexical scope.
+            # However, there is *NO* guarantee that the type-checking function
+            # created and returned by this factory resides in the same lexical
+            # scope.
+            #
+            # Suppose that type-checking function does, however. Even in that
+            # best case, *ALL* calls to that tester would still be non-portable.
+            # Why? Because those calls would now tacitly assume the original
+            # lexical scope that they were called in. Those calls are now
+            # lexically-dependent and thus could *NOT* be trivially
+            # copy-and-pasted into different lexical scopes (e.g., submodules,
+            # classes, or callables); doing so would raise exceptions at call
+            # time, due to being unable to resolve those references. Preventing
+            # users from doing something that will blow up in their test suites
+            # commits after the fact is not simply a good thing; it's really the
+            # only sane thing left.
+            #
+            # Suppose that we didn't particularly care about end user sanity,
+            # however. Even in that worst case, resolving these references would
+            # still be non-trivial, non-portable, and (perhaps most importantly)
+            # incredibly slow. Why? Because doing so would require iteratively
+            # introspecting the call stack for the first callable *NOT* residing
+            # in the "beartype" codebase. These references would then be
+            # resolved against the global and local lexical scope of that
+            # callable. While technically feasible, doing so would render
+            # higher-level "beartype" functions calling this lower-level factory
+            # (e.g., our increasingly popular public beartype.door.is_bearable()
+            # and die_if_unbearable() type-checkers) sufficiently slow as to be
+            # pragmatically infeasible.
+            if hint_refs_type_basename:
+                # Defer to a low-level getter to raise a reasonable exception.
+                get_hint_pep484585_ref_names_relative_to(
+                    # First relative forward reference in this type hint,
+                    # arbitrarily chosen for convenience.
+                    hint=hint_refs_type_basename[0],
+                    exception_prefix=(
+                        f'{EXCEPTION_PLACEHOLDER}type hint {repr(hint)} '),
+                )
+            # Else, this hint contains *NO* relative forward references.
+
+            # Unqualified basename of this type-checking function, uniquified by
+            # suffixing an arbitrary integer unique to this function.
+            func_checker_name = (
+                f'{FUNC_CHECKER_NAME_PREFIX}{next(_func_checker_name_counter)}')
+
+            # Python code snippet declaring the signature of the type-checking
+            # function function to be defined and returned by this factory.
+            code_signature = make_func_signature(
+                func_name=func_checker_name,
+                func_scope=func_scope,
+                code_signature_format=CODE_CHECKER_SIGNATURE,
+                conf=conf,
             )
-        # Else, this hint contains *NO* relative forward references.
 
-        # Unqualified basename of this type-checking function, uniquified by
-        # suffixing an arbitrary integer unique to this function.
-        func_checker_name = (
-            f'{FUNC_CHECKER_NAME_PREFIX}{next(_func_checker_name_counter)}')
+            # Python code snippet defining this type-checking function in full.
+            func_checker_code = f'{code_signature}{code_check}'
 
-        # Python code snippet declaring the signature of the type-checking
-        # function function to be defined and returned by this factory.
-        code_signature = make_func_signature(
-            func_name=func_checker_name,
-            func_scope=func_scope,
-            code_signature_format=CODE_CHECKER_SIGNATURE,
-            conf=conf,
-        )
-
-        # Python code snippet defining this type-checking function in entirety.
-        func_checker_code = f'{code_signature}{code_check}'
-
-        # ....................{ FUNCTION                   }....................
-        # Type-checking tester function to be returned.
-        func_tester = make_func(
-            func_name=func_checker_name,
-            func_code=func_checker_code,
-            func_locals=func_scope,
-            func_label='die_if_unbearable() or is_bearable() type-checker',
-            is_debug=conf.is_debug,
-        )
+            # ....................{ FUNCTION               }....................
+            # Type-checking tester function to be returned.
+            func_tester = make_func(
+                func_name=func_checker_name,
+                func_code=func_checker_code,
+                func_locals=func_scope,
+                func_label='die_if_unbearable() or is_bearable() type-checker',
+                is_debug=conf.is_debug,
+            )
+        # If one or more warnings were issued, reissue these warnings with each
+        # placeholder substring (i.e., "EXCEPTION_PLACEHOLDER" instance)
+        # replaced by a human-readable description of this callable and
+        # annotated return.
+        if warnings_issued:
+            reissue_warnings_placeholder(
+                warnings=warnings_issued, target_str=exception_prefix)
+        # Else, *NO* warnings were issued.
     # If doing so raises *ANY* exception, reraise this exception with each
     # placeholder substring (i.e., "EXCEPTION_PLACEHOLDER" instance) replaced by
     # an explanatory prefix.
     except Exception as exception:
         reraise_exception_placeholder(
-            exception=exception,
-            target_str='die_if_unbearable() or is_bearable() ',
-        )
+            exception=exception, target_str=exception_prefix)
 
     # Return this tester function.
     return func_tester  # type: ignore[return-value]
@@ -799,6 +833,18 @@ def _make_code_raiser_violation(
 
         # Pass the warnings.warn() function required to emit this warning to
         # this wrapper function as an optional hidden parameter.
+        #
+        # Note that we intentionally do *NOT* pass the higher-level
+        # issue_warning() function. Why? Efficiency, mostly. Recall that
+        # issue_warning() is *ONLY* called to pretend that warnings generated by
+        # callables both defined by and residing in this codebase are actually
+        # generated by external third-party code. Although this wrapper function
+        # is also generated by callables defined by this codebase (including
+        # this callable, of course), this wrapper function does *NOT* reside
+        # inside this codebase but instead effectively resides inside the
+        # external third-party module defining the original function this
+        # wrapper function wraps. Needlessly passing issue_warning() rather than
+        # warn() here would only consume CPU cycles for *NO* tangible gain.
         func_scope[ARG_NAME_WARN] = warn
     # Else...
     else:
@@ -807,4 +853,3 @@ def _make_code_raiser_violation(
 
     # Return this code snippet.
     return code_violation
-
