@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -31,7 +31,7 @@ This private submodule is *not* intended for importation by downstream callers.
 #
 #Specifically, rather than accept "typing" nonsense verbatim, we could instead:
 #* Detect PEP 544-compatible protocol type hints *NOT* decorated by
-#  @typing.runtime_checkable. The existing is_type_or_types_isinstanceable() tester now
+#  @typing.runtime_checkable. The existing is_type_isinstanceable() tester now
 #  detects whether arbitrary classes are isinstanceable, so just call that.
 #* Emit a non-fatal warning advising the end user to resolve this on their end.
 #* Meanwhile, beartype can simply:
@@ -56,13 +56,15 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.typing import (
     Any,
+    Optional,
     Union,
 )
 from beartype._cave._cavefast import NotImplementedType
+from beartype._cave._cavemap import NoneTypeOr
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN
 from beartype._data.func.datafunc import METHOD_NAMES_DUNDER_BINARY
 from beartype._check.checkcall import BeartypeCall
-from beartype._check.forward.fwdhint import resolve_hint
+from beartype._check.forward.fwdmain import resolve_hint
 from beartype._util.cache.map.utilmapbig import CacheUnboundedStrong
 from beartype._util.hint.utilhinttest import is_hint_uncached
 from beartype._util.hint.pep.proposal.pep484.utilpep484union import (
@@ -72,8 +74,7 @@ from beartype._util.hint.pep.proposal.pep484.utilpep484union import (
 #FIXME: Document mypy-specific coercion in the docstring as well, please.
 def coerce_func_hint_root(
     hint: object,
-    #FIXME: Rename to "pith_name" for orthogonality with everything else.
-    arg_name: str,
+    pith_name: Optional[str],
     bear_call: BeartypeCall,
     exception_prefix: str,
 ) -> object:
@@ -90,7 +91,7 @@ def coerce_func_hint_root(
     function would consume space needlessly with *no* useful benefit.
 
     Caveats
-    ----------
+    -------
     This function *cannot* be meaningfully memoized, since the passed type hint
     is *not* guaranteed to be cached somewhere. Only functions passed cached
     type hints can be meaningfully memoized. Since this high-level function
@@ -103,12 +104,13 @@ def coerce_func_hint_root(
     ----------
     hint : object
         Possibly PEP-noncompliant type hint to be possibly coerced.
-    arg_name : str
+    pith_name : Optional[str]
         Either:
 
-        * If this hint annotates a parameter of that callable, the name of that
+        * If this hint annotates a parameter of some callable, the name of that
           parameter.
-        * If this hint annotates the return of that callable, ``"return"``.
+        * If this hint annotates the return of some callable, ``"return"``.
+        * Else, :data:`None`.
     bear_call : BeartypeCall
         Decorated callable annotated by this hint.
     exception_prefix : str
@@ -116,7 +118,7 @@ def coerce_func_hint_root(
         exception message.
 
     Returns
-    ----------
+    -------
     object
         Either:
 
@@ -124,9 +126,11 @@ def coerce_func_hint_root(
           type hint coerced from this hint.
         * Else, this hint as is unmodified.
     '''
-    assert isinstance(arg_name, str), f'{repr(arg_name)} not string.'
+    assert isinstance(pith_name, NoneTypeOr[str]), (
+        f'{repr(pith_name)} neither string nor "None".')
     assert bear_call.__class__ is BeartypeCall, (
         f'{repr(bear_call)} not @beartype call.')
+    # print(f'Coercing pith "{pith_name}" annotated by type hint {repr(hint)}...')
 
     # ..................{ FORWARD REFERENCE                  }..................
     # If this hint is stringified (e.g., as a PEP 484- or 563-compliant forward
@@ -147,7 +151,7 @@ def coerce_func_hint_root(
     # If...
     if (
         # This hint annotates the return for the decorated callable *AND*...
-        arg_name == ARG_NAME_RETURN and
+        pith_name == ARG_NAME_RETURN and
         # The decorated callable is a binary dunder method (e.g., __eq__())...
         bear_call.func_wrapper_name in METHOD_NAMES_DUNDER_BINARY
     ):
@@ -223,7 +227,7 @@ def coerce_hint_root(hint: object, exception_prefix: str) -> object:
     :func:`callable_cached` decorator). See caveats that follow.
 
     Caveats
-    ----------
+    -------
     This function *cannot* be meaningfully memoized, since the passed type hint
     is *not* guaranteed to be cached somewhere. Only functions passed cached
     type hints can be meaningfully memoized. Since this high-level function
@@ -241,7 +245,7 @@ def coerce_hint_root(hint: object, exception_prefix: str) -> object:
         exception message.
 
     Returns
-    ----------
+    -------
     object
         Either:
 
@@ -354,25 +358,25 @@ def coerce_hint_any(hint: object) -> Any:
     :mod:`beartype` for standard type hints.
 
     Caveats
-    ----------
+    -------
     This function *cannot* be meaningfully memoized, since the passed type hint
     is *not* guaranteed to be cached somewhere. Only functions passed cached
     type hints can be meaningfully memoized. Since this high-level function
-    internally defers to unmemoized low-level functions that are ``O(n)`` for
-    ``n`` the size of the inheritance hierarchy of this hint, this function
-    should be called sparingly.
+    internally defers to unmemoized low-level functions that are :math:`O(n)`
+    for :math:`n` the size of the inheritance hierarchy of this hint, this
+    function should be called sparingly.
 
     This function intentionally does *not* cache :pep:`484`-compliant generics
     subscripted by type variables under Python < 3.9. Those hints are
     technically uncached but silently treated by this function as self-cached
     and thus preserved as is. Why? Because correctly detecting those hints as
-    uncached would require an unmemoized ``O(n)`` search across the inheritance
-    hierarchy of *all* passed objects and thus all type hints annotating
-    callables decorated by :func:`beartype.beartype`. Since this failure only
-    affects obsolete Python versions *and* since the only harms induced by this
-    failure are a slight increase in space and time consumption for edge-case
-    type hints unlikely to actually be used in real-world code, this tradeoff
-    is more than acceptable. We're not the bad guy here. Right?
+    uncached would require an unmemoized :math:`O(n)` search across the
+    inheritance hierarchy of *all* passed objects and thus all type hints
+    annotating callables decorated by :func:`beartype.beartype`. Since this
+    failure only affects obsolete Python versions *and* since the only harms
+    induced by this failure are a slight increase in space and time consumption
+    for edge-case type hints unlikely to actually be used in real-world code,
+    this tradeoff is more than acceptable. We're not the bad guy here. Right?
 
     Parameters
     ----------
@@ -380,7 +384,7 @@ def coerce_hint_any(hint: object) -> Any:
         Type hint to be possibly coerced.
 
     Returns
-    ----------
+    -------
     object
         Either:
 
@@ -402,16 +406,16 @@ def coerce_hint_any(hint: object) -> Any:
     #   this function. In this case, replace this subsequent copy by the first
     #   copy of this hint originally passed to a prior call of this function.
     if is_hint_uncached(hint):
-        return _HINT_REPR_TO_SINGLETON.cache_or_get_cached_value(
+        # print(f'Self-caching type hint {repr(hint)}...')
+        return _hint_repr_to_hint.cache_or_get_cached_value(
             key=repr(hint), value=hint)
-        # return _HINT_REPR_TO_SINGLETON.cache_or_get_cached_value(key=repr(hint), value=hint)
     # Else, this hint is (hopefully) self-caching.
 
     # Return this uncoerced hint as is.
     return hint
 
 # ....................{ PRIVATE ~ mappings                 }....................
-_HINT_REPR_TO_SINGLETON = CacheUnboundedStrong()
+_hint_repr_to_hint = CacheUnboundedStrong()
 '''
 **Type hint cache** (i.e., thread-safe cache mapping from the machine-readable
 representations of all non-self-cached type hints to cached singleton instances
@@ -434,7 +438,7 @@ This cache does *not* cache:
   importation resembling ``from typing import Dict`` preceded that type hint).
 
 Design
---------------
+------
 **This dictionary is intentionally thread-safe.** Why? Because this dictionary
 is used to modify the ``__attributes__`` dunder variable of arbitrary callables.
 Since most such callables are either module- or class-scoped, that variable is
