@@ -14,7 +14,12 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 import beartype #  <-- satisfy mypy [note to self: i can't stand you, mypy]
-from ast import AST
+from ast import (
+    AST,
+    AsyncFunctionDef,
+    ClassDef,
+    FunctionDef,
+)
 from beartype.typing import (
     AbstractSet,
     Any,
@@ -39,6 +44,7 @@ from beartype._cave._cavefast import (
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
+from collections.abc import Callable as CallableABC
 from importlib.abc import PathEntryFinder
 from pathlib import Path
 from types import (
@@ -47,8 +53,68 @@ from types import (
     GeneratorType,
 )
 
+# ....................{ TYPEVARS                           }....................
+S = TypeVar('S')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.T` type variable.
+'''
+
+
+T = TypeVar('T')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.S` type variable.
+'''
+
+
+CallableT = TypeVar('CallableT', bound=CallableABC)
+'''
+**Callable type variable** (i.e., bound to match *only* callables).
+'''
+
+
+NodeT = TypeVar('NodeT', bound=AST)
+'''
+**Node type variable** (i.e., type variable constrained to match *only* abstract
+syntax tree (AST) nodes).
+'''
+
 # ....................{ AST                                }....................
-ListNodes = List[AST]
+NodeCallable = Union[FunctionDef, AsyncFunctionDef]
+'''
+PEP-compliant type hint matching a **callable node** (i.e., abstract syntax tree
+(AST) node encapsulating the definition of a pure-Python function or method that
+is either synchronous or asynchronous).
+'''
+
+
+NodeDecoratable = Union[NodeCallable, ClassDef]
+'''
+PEP-compliant type hint matching a **decoratable node** (i.e., abstract syntax
+tree (AST) node encapsulating the definition of a pure-Python object supporting
+decoration by one or more ``"@"``-prefixed decorations, including both
+pure-Python classes *and* callables).
+'''
+
+
+NodeVisitResult = Optional[Union[AST, List[AST]]]
+'''
+PEP-compliant type hint matching a **node visitation result** (i.e., object
+returned by any visitor method of an :class:`ast.NodeVisitor` subclass).
+
+Specifically, this hint matches either:
+
+* A single node, in which case a visitor method has effectively preserved the
+  currently visited node passed to that method in the AST.
+* A list of zero or more nodes, in which case a visitor method has replaced the
+  currently visited node passed to that method with those nodes in the AST.
+* :data:`None`, in which case a visitor method has effectively destroyed the
+  currently visited node passed to that method from the AST.
+'''
+
+
+NodesList = List[AST]
 '''
 PEP-compliant type hint matching an **abstract syntax tree (AST) node list**
 (i.e., list of zero or more AST nodes).
@@ -143,15 +209,6 @@ checkers (e.g., :mod:`mypy`) and type-aware IDEs (e.g., VSCode) that the
 # ....................{ CALLABLE                           }....................
 # Callable-specific type hints *NOT* required by subsequent type hints below.
 
-BeartypeDecorator = Callable[[BeartypeableT], BeartypeableT]
-'''
-PEP-compliant type hint matching a **beartype-like decorator** (i.e., callable
-presumably decorating a passed object by the :func:`beartype.beartype` decorator
-under a possibly non-default beartype configuration and returning the resulting
-decorated object).
-'''
-
-
 CallableRaiser = Callable[[object], None]
 '''
 PEP-compliant type hint matching a **raiser callable** (i.e., arbitrary callable
