@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -30,15 +30,6 @@ from types import (
     MethodType,
 )
 
-# ....................{ CONSTANTS                          }....................
-#FIXME: Shift into the "beartype._date" subpackage somewhere, please.
-#FIXME: Unit test us up, please.
-FUNC_CODEOBJ_NAME_MODULE = '<module>'
-'''
-String constant unconditionally assigned to the ``co_name`` instance variables
-of the code objects of all pure-Python modules.
-'''
-
 # ....................{ GETTERS                            }....................
 def get_func_codeobj(
     # Mandatory parameters.
@@ -47,6 +38,7 @@ def get_func_codeobj(
     # Optional parameters.
     is_unwrap: bool = False,
     exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_prefix: str = '',
 ) -> CodeType:
     '''
     **Code object** (i.e., instance of the :class:`CodeType` type) underlying
@@ -103,14 +95,17 @@ def get_func_codeobj(
     exception_cls : TypeException, optional
         Type of exception to be raised in the event of a fatal error. Defaults
         to :class:`._BeartypeUtilCallableException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the message of any exception raised in
+        the event of a fatal error. Defaults to the empty string.
 
     Returns
-    ----------
+    -------
     CodeType
         Code object underlying this codeobjable.
 
     Raises
-    ----------
+    ------
     exception_cls
          If this codeobjable has *no* code object and is thus *not* pure-Python.
     '''
@@ -125,7 +120,11 @@ def get_func_codeobj(
         from beartype._util.func.utilfunctest import die_unless_func_python
 
         # Raise an exception.
-        die_unless_func_python(func=func, exception_cls=exception_cls)
+        die_unless_func_python(
+            func=func,
+            exception_cls=exception_cls,
+            exception_prefix=exception_prefix,
+        )
     # Else, this callable is pure-Python and this code object exists.
 
     # Return this code object.
@@ -185,7 +184,7 @@ def get_func_codeobj_or_none(
         for both efficiency and disambiguity.
 
     Returns
-    ----------
+    -------
     Optional[CodeType]
         Either:
 
@@ -194,7 +193,7 @@ def get_func_codeobj_or_none(
         * Else, :data:`None`.
 
     See Also
-    ----------
+    --------
     :func:`.get_func_codeobj`
         Further details.
     '''
@@ -284,21 +283,18 @@ def get_func_codeobj_or_none(
 
 # ....................{ GETTERS                            }....................
 #FIXME: Unit test us up, please.
-def get_func_codeobj_name(func: Codeobjable, **kwargs) -> str:
+def get_func_codeobj_basename(func: Codeobjable, **kwargs) -> str:
     '''
-    Fully-qualified name or unqualified basename (contextually depending on the
-    version of the active Python interpreter) of the passed **codeobjable**
-    (i.e., pure-Python object directly associated with a code object) if this
-    object is codeobjable *or* raise an exception otherwise (e.g., if this
-    object is *not* codeobjable).
+    Unqualified basename (contextually depending on the version of the active
+    Python interpreter) of the passed **codeobjable** (i.e., pure-Python object
+    directly associated with a code object) if this object is codeobjable *or*
+    raise an exception otherwise (e.g., if this object is *not* codeobjable).
 
     Specifically, this getter returns:
 
-    * If the active Python interpreter targets Python >= 3.11 and thus defines
-      the ``co_qualname`` attribute on code objects, the value of that attribute
-      on the code object providing the fully-qualified name of this codeobjable.
-    * Else, the value of the ``co_name`` attribute on the code object providing
-      the unqualified basename of this codeobjable.
+    * If the active Python interpreter targets Python >= 3.11, the value of the
+      the ``co_qualname`` attribute on this code object.
+    * Else, the value of the ``co_name`` attribute on this code object.
 
     Parameters
     ----------
@@ -309,7 +305,7 @@ def get_func_codeobj_name(func: Codeobjable, **kwargs) -> str:
     :func:`.get_func_codeobj` getter.
 
     Raises
-    ----------
+    ------
     exception_cls
          If this codeobjable has *no* code object and is thus *not* pure-Python.
     '''
