@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -12,25 +12,21 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
-from beartype.typing import (
-    Any,
-)
+from beartype.typing import Any
 from beartype._data.hint.datahintfactory import TypeGuard
 from beartype._data.hint.datahinttyping import (
     Codeobjable,
     TypeException,
 )
+from beartype._util.cache.utilcachecall import callable_cached
+from beartype._util.func.arg.utilfuncargget import (
+    get_func_args_nonvariadic_len)
 from beartype._util.func.arg.utilfuncargtest import (
     is_func_arg_variadic_positional,
     is_func_arg_variadic_keyword,
 )
-from beartype._util.func.utilfunccodeobj import (
-    get_func_codeobj_or_none,
-)
-from collections.abc import (
-    Callable,
-    # Generator,
-)
+from beartype._util.func.utilfunccodeobj import get_func_codeobj_or_none
+from collections.abc import Callable
 from inspect import (
     CO_ASYNC_GENERATOR,
     CO_COROUTINE,
@@ -48,7 +44,7 @@ Python initializes the names of *all* lambda functions to this lambda-specific
 placeholder string on lambda definition.
 
 Caveats
-----------
+-------
 **Usage of this placeholder to differentiate lambda from non-lambda callables
 invites false positives in unlikely edge cases.** Technically, malicious third
 parties may externally change the name of any lambda function *after* defining
@@ -89,17 +85,17 @@ def die_unless_func_python(
         exception message. Defaults to the empty string.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
          If the passed callable is C-based.
 
     See Also
-    ----------
-    :func:`is_func_python`
+    --------
+    :func:`.is_func_python`
         Further details.
     '''
 
-    # If this callable is *NOT* pure-Python, raise an exception.
+    # If that callable is *NOT* pure-Python, raise an exception.
     if not is_func_python(func):
         assert isinstance(exception_cls, type), (
             f'{repr(exception_cls)} not class.')
@@ -108,15 +104,15 @@ def die_unless_func_python(
         assert isinstance(exception_prefix, str), (
             f'{repr(exception_prefix)} not string.')
 
-        # If this callable is uncallable, raise an appropriate exception.
+        # If that callable is uncallable, raise an appropriate exception.
         if not callable(func):
             raise exception_cls(f'{exception_prefix}{repr(func)} not callable.')
-        # Else, this callable is callable.
+        # Else, that callable is callable.
 
         # Raise a human-readable exception.
         raise exception_cls(
             f'{exception_prefix}{repr(func)} not pure-Python function.')
-    # Else, this callable is pure-Python.
+    # Else, that callable is pure-Python.
 
 # ....................{ VALIDATORS ~ descriptors           }....................
 def die_unless_func_classmethod(
@@ -147,13 +143,13 @@ def die_unless_func_classmethod(
         exception message. Defaults to the empty string.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
          If the passed object is *not* a class method descriptor.
 
     See Also
-    ----------
-    :func:`is_func_classmethod`
+    --------
+    :func:`.is_func_classmethod`
         Further details.
     '''
 
@@ -201,13 +197,13 @@ def die_unless_func_property(
         exception message. Defaults to the empty string.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
          If the passed object is *not* a property method descriptor.
 
     See Also
-    ----------
-    :func:`is_func_property`
+    --------
+    :func:`.is_func_property`
         Further details.
     '''
 
@@ -256,13 +252,13 @@ def die_unless_func_staticmethod(
         exception message. Defaults to the empty string.
 
     Raises
-    ----------
-    :exc:`exception_cls`
+    ------
+    exception_cls
          If the passed object is *not* a static method descriptor.
 
     See Also
-    ----------
-    :func:`is_func_staticmethod`
+    --------
+    :func:`.is_func_staticmethod`
         Further details.
     '''
 
@@ -283,9 +279,9 @@ def die_unless_func_staticmethod(
     # Else, this object is a static method descriptor.
 
 # ....................{ TESTERS                            }....................
-def is_func_lambda(func: Any) -> bool:
+def is_func_lambda(func: Any) -> TypeGuard[Callable]:
     '''
-    ``True`` only if the passed object is a **pure-Python lambda function**
+    :data:`True` only if the passed object is a **pure-Python lambda function**
     (i.e., function declared as a ``lambda`` expression embedded in a larger
     statement rather than as a full-blown ``def`` statement).
 
@@ -295,9 +291,9 @@ def is_func_lambda(func: Any) -> bool:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
-        ``True`` only if this object is a pure-Python lambda function.
+        :data:`True` only if this object is a pure-Python lambda function.
     '''
 
     # Return true only if this both...
@@ -331,7 +327,7 @@ def is_func_python(func: object) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is a pure-Python callable.
     '''
@@ -340,41 +336,6 @@ def is_func_python(func: object) -> TypeGuard[Callable]:
     # C-based callables are associated with *NO* code objects.
     return get_func_codeobj_or_none(func) is not None
 
-
-def is_func_wrapper(func: Any) -> TypeGuard[Callable]:
-    '''
-    :data:`True` only if the passed object is a **callable wrapper** (i.e.,
-    object created by the standard :func:`functools.wraps` decorator for
-    wrapping a pure-Python callable with additional functionality defined by a
-    higher-level decorator).
-
-    Note that this tester returns :data:`True` for both pure-Python and C-based
-    callable wrappers. As an example of the latter, the standard
-    :func:`functools.lru_cache` decorator creates and returns low-level C-based
-    callable wrappers of the private type :class:`functools._lru_cache_wrapper`
-    wrapping pure-Python callables.
-
-    Parameters
-    ----------
-    func : object
-        Object to be inspected.
-
-    Returns
-    ----------
-    bool
-        :data:`True` only if this object is a callable wrapper.
-    '''
-
-    # Return true only if this object defines a dunder attribute uniquely
-    # specific to the @functools.wraps decorator.
-    #
-    # Technically, *ANY* callable (including non-wrappers *NOT* created by the
-    # @functools.wraps decorator) could trivially define this attribute; ergo,
-    # this invites the possibility of false positives. Pragmatically, doing so
-    # would violate ad-hoc standards and real-world practice across the
-    # open-source ecosystem; ergo, this effectively excludes false positives.
-    return hasattr(func, '__wrapped__')
-
 # ....................{ TESTERS ~ descriptor               }....................
 def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     '''
@@ -386,7 +347,7 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     instance attributes).
 
     Caveats
-    ----------
+    -------
     Class method objects are *only* directly accessible via the low-level
     :attr:`object.__dict__` dictionary. When accessed as class or instance
     attributes, class methods reduce to instances of the standard
@@ -401,7 +362,7 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is a C-based unbound class method
         descriptor.
@@ -420,7 +381,7 @@ def is_func_property(func: Any) -> TypeGuard[property]:
     than instance attribute).
 
     Caveats
-    ----------
+    -------
     Property objects are directly accessible both as class attributes *and* via
     the low-level :attr:`object.__dict__` dictionary. Property objects are *not*
     accessible as instance attributes, for hopefully obvious reasons.
@@ -434,7 +395,7 @@ def is_func_property(func: Any) -> TypeGuard[property]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is a pure-Python property.
     '''
@@ -453,7 +414,7 @@ def is_func_staticmethod(func: Any) -> TypeGuard[staticmethod]:
     attributes).
 
     Caveats
-    ----------
+    -------
     Static method objects are *only* directly accessible via the low-level
     :attr:`object.__dict__` dictionary. When accessed as class or instance
     attributes, static methods reduce to instances of the standard
@@ -468,7 +429,7 @@ def is_func_staticmethod(func: Any) -> TypeGuard[staticmethod]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is a pure-Python static method.
     '''
@@ -492,12 +453,12 @@ def is_func_async(func: object) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is an asynchronous callable.
 
     See Also
-    ----------
+    --------
     :func:`inspect.iscoroutinefunction`
     :func:`inspect.isasyncgenfunction`
         Stdlib functions strongly inspiring this implementation.
@@ -554,12 +515,12 @@ def is_func_coro(func: object) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is an asynchronous coroutine factory.
 
     See Also
-    ----------
+    --------
     :func:`inspect.iscoroutinefunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -592,12 +553,12 @@ def is_func_async_generator(func: object) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is an asynchronous generator.
 
     See Also
-    ----------
+    --------
     :func:`inspect.isasyncgenfunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -629,12 +590,12 @@ def is_func_sync_generator(func: object) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this object is a synchronous generator.
 
     See Also
-    ----------
+    --------
     :func:`inspect.isgeneratorfunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -694,7 +655,7 @@ def is_func_nested(func: Callable) -> bool:
         Callable to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this callable is nested.
     '''
@@ -767,7 +728,7 @@ def is_func_closure(func: Any) -> TypeGuard[Callable]:
         Callable to be inspected.
 
     Returns
-    ----------
+    -------
     bool
         :data:`True` only if this callable is a closure.
     '''
@@ -779,21 +740,60 @@ def is_func_closure(func: Any) -> TypeGuard[Callable]:
     # * If that callable is C-based, undefined.
     return getattr(func, '__closure__', None) is not None
 
-
-def is_func_closure_isomorphic(func: Any) -> TypeGuard[Callable]:
+# ....................{ TESTERS ~ wrapper                  }....................
+def is_func_wrapper(func: Any) -> TypeGuard[Callable]:
     '''
-    :data:`True` only if the passed object is an **isomorphic decorator
-    closure** (i.e., closure both defined and returned by a decorator such that
-    that closure isomorphically preserves both the number and types of all
-    passed parameters and returns, implemented as a closure accepting only a
-    variadic positional argument and a variadic keyword argument).
+    :data:`True` only if the passed object is a **callable wrapper** (i.e.,
+    callable decorated by the standard :func:`functools.wraps` decorator for
+    wrapping a pure-Python callable with additional functionality defined by a
+    higher-level decorator).
+
+    Note that this tester returns :data:`True` for both pure-Python and C-based
+    callable wrappers. As an example of the latter, the standard
+    :func:`functools.lru_cache` decorator creates and returns low-level C-based
+    callable wrappers of the private type :class:`functools._lru_cache_wrapper`
+    wrapping pure-Python callables.
+
+    Parameters
+    ----------
+    func : object
+        Object to be inspected.
+
+    Returns
+    -------
+    bool
+        :data:`True` only if this object is a callable wrapper.
+    '''
+
+    # Return true only if this object defines a dunder attribute uniquely
+    # specific to the @functools.wraps decorator.
+    #
+    # Technically, *ANY* callable (including non-wrappers *NOT* created by the
+    # @functools.wraps decorator) could trivially define this attribute; ergo,
+    # this invites the possibility of false positives. Pragmatically, doing so
+    # would violate ad-hoc standards and real-world practice across the
+    # open-source ecosystem; ergo, this effectively excludes false positives.
+    return hasattr(func, '__wrapped__')
+
+
+@callable_cached
+def is_func_wrapper_isomorphic(func: Any) -> TypeGuard[Callable]:
+    '''
+    :data:`True` only if the passed object is an **isomorphic wrapper** (i.e.,
+    callable decorated by the standard :func:`functools.wraps` decorator for
+    wrapping a pure-Python callable with additional functionality defined by a
+    higher-level decorator such that that wrapper isomorphically preserves both
+    the number and types of all passed parameters and returns by accepting only
+    a variadic positional argument and a variadic keyword argument).
 
     This tester enables callers to detect when a user-defined callable has been
     decorated by an isomorphic decorator, which constitutes *most* real-world
     decorators of interest.
 
+    This tester is memoized for efficiency.
+
     Caveats
-    ----------
+    -------
     **This tester is merely a heuristic** -- albeit a reasonably robust
     heuristic likely to succeed in almost all real-world use cases. Nonetheless,
     this tester *could* return false positives and negatives in edge cases.
@@ -804,15 +804,15 @@ def is_func_closure_isomorphic(func: Any) -> TypeGuard[Callable]:
         Object to be inspected.
 
     Returns
-    ----------
+    -------
     bool
-        :data:`True` only if this object is an isomorphic decorator closure.
+        :data:`True` only if this object is an isomorphic decorator wrapper.
     '''
 
-    # If the passed callable is *NOT* a closure, immediately return false.
-    if not is_func_closure(func):
+    # If the passed callable is *NOT* a wrapper, immediately return false.
+    if not is_func_wrapper(func):
         return False
-    # Else, that callable is a closure.
+    # Else, that callable is a wrapper.
 
     # Code object underlying that callable as is (rather than possibly unwrapped
     # to another code object entirely) if that callable is pure-Python *OR*
@@ -825,6 +825,8 @@ def is_func_closure_isomorphic(func: Any) -> TypeGuard[Callable]:
         func_codeobj is not None and
         # That callable accepts a variadic positional argument *AND*...
         is_func_arg_variadic_positional(func_codeobj) and
-        # That callable accepts a variadic keyword argument.
-        is_func_arg_variadic_keyword(func_codeobj)
+        # That callable accepts a variadic keyword argument *AND*...
+        is_func_arg_variadic_keyword(func_codeobj) and
+        # That callable accepts *NO* non-variadic arguments.
+        get_func_args_nonvariadic_len(func_codeobj) == 0
     )
