@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -87,15 +87,15 @@ def die_unless_hint(
     # BEGIN: Synchronize changes here with is_hint() below.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-    # If this hint is PEP-compliant, raise an exception only if this hint is
-    # currently unsupported by @beartype.
+    # If this hint is PEP-compliant *AND* currently unsupported by @beartype,
+    # raise an exception.
     if is_hint_pep(hint):
         die_if_hint_pep_unsupported(
             hint=hint, exception_prefix=exception_prefix)
     # Else, this hint is *NOT* PEP-compliant. In this case...
 
-    # Raise an exception only if this hint is also *NOT* PEP-noncompliant. By
-    # definition, all PEP-noncompliant type hints are supported by @beartype.
+    # If this PEP-noncompliant hint but still currently unsupported by
+    # @beartype, raise an exception.
     die_unless_hint_nonpep(hint=hint, exception_prefix=exception_prefix)
 
 # ....................{ TESTERS                            }....................
@@ -168,8 +168,11 @@ def is_hint_ignorable(hint: object) -> bool:
     # Avoid circular import dependencies.
     from beartype._util.hint.utilhintget import get_hint_repr
 
+    # Machine-readable representation of this hint.
+    hint_repr = get_hint_repr(hint)
+
     # If this hint is shallowly ignorable, return true.
-    if get_hint_repr(hint) in HINTS_REPR_IGNORABLE_SHALLOW:
+    if hint_repr in HINTS_REPR_IGNORABLE_SHALLOW:
         return True
     # Else, this hint is *NOT* shallowly ignorable.
     #
@@ -222,7 +225,7 @@ def is_hint_uncached(hint: object) -> bool:
 
     # Avoid circular import dependencies.
     from beartype._util.hint.pep.proposal.utilpep585 import (
-        is_hint_pep585_builtin)
+        is_hint_pep585_builtin_subscripted)
     from beartype._util.hint.pep.proposal.utilpep604 import is_hint_pep604
 
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -241,7 +244,7 @@ def is_hint_uncached(hint: object) -> bool:
         # Note that this additionally includes all third-party type hints that
         # derive from the "types.GenericAlias" superclass, including:
         # * "numpy.typing.NDArray[...]" type hints.
-        is_hint_pep585_builtin(hint) or
+        is_hint_pep585_builtin_subscripted(hint) or
         # PEP 604-compliant (e.g., "int | str"), this hint is *NOT* self-caching
         # (e.g., "int | str is not int | str").
         #
