@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -233,10 +233,10 @@ def skip_if_pypy():
     '''
 
     # Defer test-specific imports.
-    from beartype._util.py.utilpyinterpreter import is_py_pypy
+    from beartype._util.py.utilpyinterpreter import is_python_pypy
 
     # Skip this test if the active Python interpreter is PyPy.
-    return skip_if(is_py_pypy(), reason='Incompatible with PyPy.')
+    return skip_if(is_python_pypy(), reason='Incompatible with PyPy.')
 
 
 def skip_if_python_version_greater_than_or_equal_to(version: str):
@@ -343,7 +343,16 @@ def skip_unless_package(
     # Skip the decorated test or fixture unless the requisite dunder submodule
     # declared by this package satisfies these requirements.
     return skip_unless_module(
-        module_name=f'{package_name}.__init__',
+        module_name=package_name,
+
+        #FIXME: Fascinatingly, this submodule importation worked for *ALL*
+        #third-party packages except PyTorch. For unknown reasons, attempting to
+        #dynamically import the "torch.__init__" submodule raises:
+        #    NameError: name '_C' is not defined
+        #
+        #Thankfully, directly importing the package as is suffices. *shrug*
+        # module_name=f'{package_name}.__init__',
+
         minimum_version=minimum_version,
     )
 
