@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -30,9 +30,9 @@ def raises_uncached(exception_cls: TypeException) -> 'ExceptionInfo':
     Context manager validating that the block exercised by this manager raises
     a **cached exception** (i.e., whose message previously containing one or
     more instances of the magic
-    :data:`beartype._util.error.utilerror.EXCEPTION_PLACEHOLDER`
-    substring since replaced by the
-    :func:`beartype._util.error.utilerror.reraise_exception_placeholder`
+    :data:`beartype._data.error.dataerrmagic.EXCEPTION_PLACEHOLDER` substring
+    since replaced by the
+    :func:`beartype._util.error.utilerrraise.reraise_exception_placeholder`
     function) of the passed type.
 
     Parameters
@@ -41,20 +41,19 @@ def raises_uncached(exception_cls: TypeException) -> 'ExceptionInfo':
         Type of cached exception expected to be raised by this block.
 
     Returns
-    ----------
+    -------
     :class:`pytest.nodes.ExceptionInfo`
         :mod:`pytest`-specific object collecting metadata on the cached
         exception of this type raised by this block.
 
     See Also
-    ----------
+    --------
     https://docs.pytest.org/en/stable/reference.html#pytest._code.ExceptionInfo
         Official :class:`pytest.nodes.ExceptionInfo` documentation.
     '''
 
     # Defer test-specific imports.
-    from beartype._util.error.utilerror import (
-        EXCEPTION_PLACEHOLDER)
+    from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 
     # Within a "pytest"-specific context manager validating this contextual
     # block to raise an exception of this type, perform the body of that block.
