@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2024 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -31,16 +31,12 @@ from beartype import beartype
 from beartype.typing import (
     Generic,
     List,
-    Type,
-    TypeVar,
+    Optional,
+    Sequence,
+    Type,  # <-- intentionally imported due to being embedded in strings below
     Union,
 )
-
-# ....................{ PRIVATE ~ hints                    }....................
-_T = TypeVar('_T')
-'''
-Arbitrary type variable reference in type hints defined below.
-'''
+from beartype._data.hint.datahinttyping import T
 
 # ....................{ FUNCTIONS ~ pep : discrete         }....................
 # Arbitrary functions annotated by PEP-compliant forward references defined as
@@ -53,8 +49,8 @@ TheDarkestForwardRefOfTheYear = (
 def the_woods_are_lovely(dark_and_deep: TheDarkestForwardRefOfTheYear) -> (
     TheDarkestForwardRefOfTheYear):
     '''
-    Decorated function annotated by a fully-qualified forward reference
-    referring to a type that has yet to be declared.
+    :func:`beartype.beartype`-decorated function annotated by a fully-qualified
+    forward reference referring to a type that has yet to be declared.
     '''
 
     return dark_and_deep
@@ -64,8 +60,8 @@ def the_woods_are_lovely(dark_and_deep: TheDarkestForwardRefOfTheYear) -> (
 def stopping_by_woods_on(a_snowy_evening: 'TheDarkestEveningOfTheYear') -> (
     'TheDarkestEveningOfTheYear'):
     '''
-    Decorated function annotated by a relative forward reference referring to a
-    type that has yet to be declared.
+    :func:`beartype.beartype`-decorated function annotated by a relative forward
+    reference referring to a type that has yet to be declared.
     '''
 
     return a_snowy_evening
@@ -76,12 +72,25 @@ TheDarkestUnionOfTheYear = Union[complex, 'TheDarkestEveningOfTheYear', bytes]
 def but_i_have_promises(to_keep: TheDarkestUnionOfTheYear) -> (
     TheDarkestUnionOfTheYear):
     '''
-    Decorated function annotated by a union of arbitrary types *and* a relative
-    forward reference referring to a type that has yet to be declared.
+    :func:`beartype.beartype`-decorated function annotated by a union of
+    arbitrary types *and* a relative forward reference referring to a type that
+    has yet to be declared.
     '''
 
     return to_keep
 
+
+NearTheShore = Optional[Sequence['TheDarkestEveningOfTheYear']]
+@beartype
+def a_little_shallop(floating: NearTheShore = ()) -> NearTheShore:
+    '''
+    :func:`beartype.beartype`-decorated function accepting an optional parameter
+    annotated by a union of arbitrary types *and* a relative forward reference
+    referring to a type that has yet to be declared.
+    '''
+
+    return floating
+
 # ....................{ FUNCTIONS ~ pep : composite        }....................
 # Arbitrary functions annotated by PEP-compliant forward references defined as
 # non-trivial Python expressions (i.e., strings that are *NOT* reducible to
@@ -99,9 +108,9 @@ def its_fields_of_snow(
     and_pinnacles_of_ice: 'List[TheDarkestForwardRefOfTheYear]') -> (
     TheDarkestForwardRefOfTheYear):
     '''
-    Decorated function annotated by a composite type hint defined as a standard
-    type hint subscripted by a relative forward reference referring to a type
-    that has yet to be declared.
+    :func:`beartype.beartype`-decorated function annotated by a composite type
+    hint defined as a standard type hint subscripted by a relative forward
+    reference referring to a type that has yet to be declared.
     '''
 
     return and_pinnacles_of_ice[0]
@@ -112,11 +121,11 @@ TheDarkestSubclassOfTheYear = 'Type[TheDarkestEveningOfTheYear]'
 def the_dry_leaf(rustles_in_the_brake: TheDarkestSubclassOfTheYear) -> (
     TheDarkestSubclassOfTheYear):
     '''
-    Decorated function annotated by a composite type hint defined as a
-    ``beartype.typing.Type[...]` hint subscripted by a relative forward
-    reference referring to a type that has yet to be declared, exercising an
-    edge case with respect to proxying of :func:`issubclass` type-checks in
-    forward reference proxies.
+    :func:`beartype.beartype`-decorated function annotated by a composite type
+    hint defined as a ``beartype.typing.Type[...]`` hint subscripted by a
+    relative forward reference referring to a type that has yet to be declared,
+    exercising an edge case with respect to proxying of :func:`issubclass`
+    type-checks in forward reference proxies.
 
     See Also
     --------
@@ -152,14 +161,14 @@ class TheDarkestEveningOfTheYear(str):
     pass
 
 
-class WithSluggishSurge(Generic[_T]):
+class WithSluggishSurge(Generic[T]):
     '''
     Arbitrary generic declaring a method annotated by a forward reference
     referring to an instance of this same generic.
     '''
 
     @beartype
-    def or_where_the_secret_caves(self) -> 'WithSluggishSurge[_T]':
+    def or_where_the_secret_caves(self) -> 'WithSluggishSurge[T]':
         '''
         Arbitrary method annotated by a forward reference referring to an
         instance of this same generic.
